import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.jdbc.object.MappingSqlQueryWithParameters;

class Main {
  public static void main(String args[]) throws Exception {
    ApplicationContext ac = new ClassPathXmlApplicationContext("context.xml", Main.class);
    DataSource dataSource = (DataSource) ac.getBean("dataSource");
    //DataSource mysqlDataSource = (DataSource) ac.getBean("mysqlDataSource");


    MappingSelectCustomer mappingSelectCustomer = new MappingSelectCustomer(dataSource);
    List result = mappingSelectCustomer.execute(new Date());

  }
}
class MappingSelectCustomer extends MappingSqlQueryWithParameters {
  private final static String SQL = "select * from t_customer";
  String LAST_LOGIN_DATE = "last_login";

  MappingSelectCustomer(DataSource ds) {
      super(ds, SQL);
  }

  protected Object mapRow(ResultSet rs, int rowNum, Object[] parameters, Map context) throws SQLException {
      Customer customer = new Customer();
      customer.setId(rs.getLong("id"));
      customer.setFirstName(rs.getString("last_name"));
      customer.setLastName(rs.getString("first_name"));
      customer.setLastLogin(rs.getDate("last_login"));
      if (rs.wasNull()) customer.setLastLogin(null);
      if (context != null) {
          if (context.containsKey(LAST_LOGIN_DATE)) customer.setLastLogin((Date)context.get("lastLogin"));
      }
      return customer;
  }

  public List execute(Date defaultLastLoginDate) {
      Map<String, Object> context = new HashMap<String, Object>();
      context.put(LAST_LOGIN_DATE, defaultLastLoginDate);
      return execute(context);
  }
}


class Customer {
  private Long id;
  private String firstName;
  private String lastName;
  private Date lastLogin;
  private String comments;

  public Long getId() {
      return id;
  }

  public void setId(Long id) {
      this.id = id;
  }

  public String getFirstName() {
      return firstName;
  }

  public void setFirstName(String firstName) {
      this.firstName = firstName;
  }

  public String getLastName() {
      return lastName;
  }

  public void setLastName(String lastName) {
      this.lastName = lastName;
  }

  public Date getLastLogin() {
      return lastLogin;
  }

  public void setLastLogin(Date lastLogin) {
      this.lastLogin = lastLogin;
  }

  public String getComments() {
      return comments;
  }

  public void setComments(String comments) {
      this.comments = comments;
  }

  @Override
  public String toString() {
      final StringBuilder sb = new StringBuilder();
      sb.append("Customer");
      sb.append("{id=").append(id);
      sb.append(", firstName='").append(firstName).append('\'');
      sb.append(", lastName='").append(lastName).append('\'');
      sb.append(", lastLogin=").append(lastLogin);
      sb.append(", comments='").append(comments).append('\'');
      sb.append('}');
      return sb.toString();
  }
}
